@@ -61,6 +61,12 @@ OTC_SERVICES = {
         'service_type': 'ces',
         'append_project_id': True,
     },
+    # 'ces': {
+    #    'service_type': 'ces',
+    #    'endpoint_service_type': 'cesv1',
+    #    'set_endpoint_override': True
+    #    'append_project_id': False,
+    # },
     'cts': {
         'service_type': 'cts',
     },
@@ -101,6 +107,14 @@ OTC_SERVICES = {
     'ecs': {
         'service_type': 'ecs',
     },
+    'elb': {
+        'service_type': 'elb',
+        'replace_system': True
+    },
+    'identity': {
+        'service_type': 'identity',
+        'replace_system': True
+    },
     'kms': {
         'service_type': 'kms',
         'append_project_id': True,
@@ -108,10 +122,6 @@ OTC_SERVICES = {
     'lts': {
         'service_type': 'lts'
     },
-    'maas': {
-        'service_type': 'maas',
-        'append_project_id': True,
-    },
     'mrs': {
         'service_type': 'mrs'
     },
